@@ -28,12 +28,13 @@ private:
     }
 
     QStringList m_testFiles;
-    QMultiMap<QString, QString> m_knownFiles;
+    QMultiMap<QByteArray, QByteArray> m_knownFiles;
 
 private Q_SLOTS:
 
     void initTestCase() {
         // Expected mimetypes
+        // clang-format off
         m_knownFiles = {
             { "test_plain_text_newlines.txt",  "text/plain"},
             { "test_plain_text_file.txt",      "text/plain"},
@@ -42,6 +43,11 @@ private Q_SLOTS:
             { "test_plain_text_file_euc-jp.txt",         "text/plain"},
             { "test_plain_text_html_file_utf16.html",    "text/html"},
             { "test_plain_text_html_file_win1251.html",  "text/html"},
+            { "test_plaintext_utf8.txt",                 "text/plain"},
+            { "test_plaintext_utf16_le.txt",             "text/plain"},
+            { "test_plaintext_utf16_be.txt",             "text/plain"},
+            { "test_plaintext_utf16_le_crlf.txt",        "text/plain"},
+            { "test_plaintext_utf16_be_crlf.txt",        "text/plain"},
             { "test.avi",                      "video/vnd.avi"},
             { "test.aif",                      "audio/x-aifc"},
             { "test.ape",                      "audio/x-ape"},
@@ -56,16 +62,24 @@ private Q_SLOTS:
             { "test.flac",                     "audio/flac"},
             { "test.heif",                     "image/heif"}, // alias for image/heic
             { "test.jpg",                      "image/jpeg"},
+            { "test_canonti.jpg",              "image/jpeg"},
             { "test.jxl",                      "image/jxl"},
             { "test_libreoffice.docx",         "application/vnd.openxmlformats-officedocument.wordprocessingml.document"},
             { "test_libreoffice.pptx",         "application/vnd.openxmlformats-officedocument.presentationml.presentation"},
             { "test_libreoffice.xlsx",         "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet"},
+            { "test_word.docx",                "application/vnd.openxmlformats-officedocument.wordprocessingml.document"},
+            { "test_word_strict.docx",         "application/vnd.openxmlformats-officedocument.wordprocessingml.document"},
+            { "test_xpsdocument.xps",          "application/vnd.ms-xpsdocument"},
+            { "test_xpsdocument.oxps",         "application/oxps"},
+            { "test_pyramid.3mf",              "model/3mf"},
             { "test.m4a",                      "audio/mp4"},
             { "test_missing_content.odt",      "application/vnd.oasis.opendocument.text"},
             { "test_missing_meta.odt",         "application/vnd.oasis.opendocument.text"},
             { "test.mkv",                      "video/x-matroska"},
             { "test.mp3",                      "audio/mpeg"},
             { "test.id3v1.mp3",                "audio/mpeg"},
+            { "test.aax",                      "audio/vnd.audible.aax"},
+            { "test.aaxc",                     "audio/vnd.audible.aaxc"},
             { "test.mpc",                      "audio/x-musepack"},
             { "test_no_gps.jpg",               "image/jpeg"},
             { "test.odg",                      "application/vnd.oasis.opendocument.graphics"},
@@ -98,6 +112,7 @@ private Q_SLOTS:
             { "test_dcterms.svg",              "image/svg+xml"},
             { "test_with_container.svg",       "image/svg+xml"},
             { "test_with_metadata.svg",        "image/svg+xml"},
+            { "test_with_metadata.svgz",       "image/svg+xml-compressed"},
             { "test.wma",                      "audio/x-ms-wma"},
             { "test.wv",                       "audio/x-wavpack"},
             { "test_zero_gps.jpg",             "image/jpeg"},
@@ -109,6 +124,7 @@ private Q_SLOTS:
             { "test.it",                       "audio/x-it"},
             { "test.xm",                       "audio/x-xm"},
         };
+        // clang-format off
 
         // Collect all test files from the samplefiles directory
         QDirIterator it(filePath(), {QStringLiteral("test*")}, QDir::Files);
@@ -129,8 +145,9 @@ private Q_SLOTS:
 
         auto it = m_knownFiles.cbegin();
         while (it != m_knownFiles.cend()) {
-            QTest::addRow("%s_%s", it.key().toUtf8().constData(), it.value().toUtf8().constData())
-                << it.key() << it.value();
+            QTest::addRow("%s_%s", it.key().constData(), it.value().constData())
+                << QString::fromUtf8(it.key().constData(), -1)
+                << QString::fromUtf8(it.value().constData(), -1);
             ++it;
         }
     }
@@ -139,13 +156,14 @@ private Q_SLOTS:
     {
         QFETCH(QString, fileName);
         QFETCH(QString, mimeType);
-        QString url = filePath() + QChar('/') + fileName;
+        QString url = filePath() + QLatin1Char('/') + fileName;
 
         QMimeDatabase db;
         auto fileMime = MimeUtils::strictMimeType(url, db);
 
         QVERIFY(fileMime.isValid());
-        if (fileMime.name() == "application/xml" && mimeType == "application/x-apple-systemprofiler+xml") {
+        if (fileMime.name() == QStringLiteral("application/xml")
+            && mimeType == QStringLiteral("application/x-apple-systemprofiler+xml")) {
             // s-m-i < 2.0 didn't have application/x-apple-systemprofiler+xml yet, it's all fine
             return;
         }
@@ -183,7 +201,7 @@ private Q_SLOTS:
     {
         QFETCH(QString, fileName);
 
-        QVERIFY2(m_knownFiles.contains(fileName), "test file omitted from test suite");
+        QVERIFY2(m_knownFiles.contains(fileName.toUtf8()), "test file omitted from test suite");
     }
 
 };
